#
# spec file for package cri-tools
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define project         github.com/kubernetes-sigs/cri-tools
%define name_source1    crictl.yaml

Name:           cri-tools
Version:        1.13.0
Release:        lp150.4.2
Summary:        CLI and validation tools for Kubelet Container Runtime Interface
License:        Apache-2.0
Group:          System/Management
Url:            https://%{project}
Source0:        %{name}-%{version}.tar.xz
Source1:        %{name_source1}
Source2:        %{name}-rpmlintrc
BuildRequires:  go-go-md2man
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.11
# go1.11.3 contains sec. fixes bsc#1118897(CVE-2018-16873) bsc#1118897(CVE-2018-16873) bsc#1118899(CVE-2018-16875)
BuildRequires:  go1.11 >= 1.11.3
# disable stripping of binaries
%{go_nostrip}

%description
cri-tools provides a series of debugging and validation tools for
Kubelet CRI, which includes:
- crictl: CLI for kubelet CRI
- critest: validation test suites for kubelet CRI

%prep
%setup -q

%build
export GOPATH=$HOME/go
mkdir -pv $HOME/go/src/%{project}
rm -rf $HOME/go/src/%{project}/*
cp -avr * $HOME/go/src/%{project}
cd $HOME/go/src/%{project}

go build -buildmode=pie \
         -o bin/crictl \
         -ldflags '-X %{project}/pkg/version.Version=%{version}' \
         %{project}/cmd/crictl

go test -buildmode=pie \
        -o bin/critest \
        -ldflags '-X %{project}/pkg/version.Version=%{version}' \
        -c %{project}/cmd/critest

# compile the manpages
for md in docs/*.md
do
	go-md2man -in $md -out $md
done
rename '.md' '.1' docs/*

# generate bash-completion
./bin/crictl completion > crictl-completion

%install
cd $HOME/go/src/%{project}
install -D -m 0755 bin/crictl %{buildroot}/%{_bindir}/crictl
install -D -m 0755 bin/critest %{buildroot}/%{_bindir}/critest
install -d %{buildroot}/%{_mandir}/man1
install -D -m 0644 docs/crictl.1 %{buildroot}/%{_mandir}/man1/crictl.1
install -D -m 0644 docs/benchmark.1 %{buildroot}/%{_mandir}/man1/critest-benchmark.1
install -D -m 0644 docs/validation.1 %{buildroot}/%{_mandir}/man1/critest-validation.1
install -D -m 0644 crictl-completion %{buildroot}/%{_datadir}/bash-completion/completions/crictl
install -D -m 0644 %{SOURCE1} %{buildroot}/%{_sysconfdir}/%{name_source1}

%files
%{_bindir}/crictl
%{_bindir}/critest
%{_mandir}/man1/*
%{_datadir}/bash-completion/completions/crictl
%config(noreplace) %{_sysconfdir}/%{name_source1}
%license LICENSE

%changelog
* Tue Jan 29 2019 mmeister@suse.com
- Update cri-tools to v1.13.0, to work with k8s 1.13.
  Changelog for 1.13.0 and previous versions:
  https://github.com/kubernetes-sigs/cri-tools/blob/master/CHANGELOG.md#v1130
- Added `cri-tools-rpmlintrc` to spec file
- Generate and install bash completion for crictl.
- Provide /etc/crictl.yaml config.
  bsc#1104598
- crictl/critest: compile version
- Require golang >= 1.10
* Wed Dec 19 2018 clee@suse.com
- Refactor go to go1.11 for BuildRequires
* Wed Dec 19 2018 clee@suse.com
- Update go requirements to >= go1.11.3 to fix
  * bsc#1118897 CVE-2018-16873
    go#29230 cmd/go: remote command execution during "go get -u"
  * bsc#1118898 CVE-2018-16874
    go#29231 cmd/go: directory traversal in "go get" via curly braces in import paths
  * bsc#1118899 CVE-2018-16875
    go#29233 crypto/x509: CPU denial of service
* Fri Jun 15 2018 vrothberg@suse.com
- Bump cri-tools to v1.0.0-beta.1 (CRI v1.10.x):
  * crictl: allow short option handling
  * crictl-exec: fix argument parsing
  * Update documentation
  * Kubernetes/CRI 1.10.x compatibility
  * Minor bug fixe
* Tue Jun  5 2018 dcassany@suse.com
- Refactor %%license usage to a simpler form
* Mon Jun  4 2018 dcassany@suse.com
- Make use of %%license macro
* Mon Mar  5 2018 vrothberg@suse.com
- Use cri-tools v1.0.0-alpha.0 to be compatible to cri-o v1.9.x.
* Fri Mar  2 2018 fcastelli@suse.com
- Change buildtime requirement of go-md2man: use go-go-md2man to ensure
  package builds on IBS against sle12sp3. This change won't affect openSUSE
* Wed Feb 14 2018 jengelh@inai.de
- Description shall say what the software does now, not in the
  future.
* Mon Feb 12 2018 vrothberg@suse.com
- Add cri-tools packaging for debugging and validating tools for the Kubelet
  CRI, including the tools crictl and critest.
